#### WP analysis script (publishing) ####
setwd(here::here())
setwd("./data")
setwd("C:/r_projects/who-reacts-why/data")
load("cleaned.RData")
rm(list=setdiff(ls(), "df"))
df$baseD <- ifelse(df$baseContribution > 35, 1, 0)
df$baseD <- factor(df$baseD, levels = c(0,1), labels = c("<=35", ">35"))

#### Preparation ####
## Loading packages ##
setwd(here::here())
setwd("./scripts/osf")
library(dplyr)
library(ggplot2)
library(sjPlot)
library(tidyverse)
library(ltm)


summarySE <- function(data=NULL, measurevar, groupvars=NULL, na.rm=FALSE, #http://www.cookbook-r.com/Graphs/Plotting_means_and_error_bars_%28ggplot2%29/
                      conf.interval=.90, .drop=TRUE) {
    library(plyr)
    
    # New version of length which can handle NA's: if na.rm==T, don't count them
    length2 <- function (x, na.rm=FALSE) {
        if (na.rm) sum(!is.na(x))
        else       length(x)
    }
    
    # This does the summary. For each group's data frame, return a vector with
    # N, mean, and sd
    datac <- ddply(data, groupvars, .drop=.drop,
                   .fun = function(xx, col) {
                       c(N    = length2(xx[[col]], na.rm=na.rm),
                         mean = mean   (xx[[col]], na.rm=na.rm),
                         sd   = sd     (xx[[col]], na.rm=na.rm)
                       )
                   },
                   measurevar
    )
    
    # Rename the "mean" column    
    datac <- rename(datac, c("mean" = measurevar))
    
    datac$se <- datac$sd / sqrt(datac$N)  # Calculate standard error of the mean
    
    # Confidence interval multiplier for standard error
    # Calculate t-statistic for confidence interval: 
    # e.g., if conf.interval is .95, use .975 (above/below), and use df=N-1
    ciMult <- qt(conf.interval/2 + .5, datac$N-1)
    datac$ci <- datac$se * ciMult
    
    return(datac)
}

multiplot <- function(..., plotlist=NULL, file, cols=1, layout=NULL) {
    library(grid)
    
    # Make a list from the ... arguments and plotlist
    plots <- c(list(...), plotlist)
    
    numPlots = length(plots)
    
    # If layout is NULL, then use 'cols' to determine layout
    if (is.null(layout)) {
        # Make the panel
        # ncol: Number of columns of plots
        # nrow: Number of rows needed, calculated from # of cols
        layout <- matrix(seq(1, cols * ceiling(numPlots/cols)),
                         ncol = cols, nrow = ceiling(numPlots/cols))
    }
    
    if (numPlots==1) {
        print(plots[[1]])
        
    } else {
        # Set up the page
        grid.newpage()
        pushViewport(viewport(layout = grid.layout(nrow(layout), ncol(layout))))
        
        # Make each plot, in the correct location
        for (i in 1:numPlots) {
            # Get the i,j matrix positions of the regions that contain this subplot
            matchidx <- as.data.frame(which(layout == i, arr.ind = TRUE))
            
            print(plots[[i]], vp = viewport(layout.pos.row = matchidx$row,
                                            layout.pos.col = matchidx$col))
        }
    }
}


common_ops <-  list(theme(plot.title = element_text(size=8),
                          axis.text = element_text(size = 8),
                          axis.title = element_text(size = 8),
                          legend.position="bottom",
                          #panel.grid.major=element_blank(),
                          #panel.grid.minor=element_blank(),
                          #  panel.border=element_blank(),
                          axis.line=element_line(),
                          text=element_text()))
#### Participants ####
nrow(df) # number of participants (n)
mean(df$age.S2, na.rm = T) # mean age
sd(df$age.S2, na.rm = T) # sd age
median(df$age.S2, na.rm = T) # median age
table(df$gender.S2) # gender distribution
df$hh.incomeF[median(df$hh.income)] # median income category


#### Prediciton of Trait Reactance ####

lm <- lm(ReactanceAFBS ~ age.S2 + gender.S2 + education.S2 + hh.income + relevel(PO, ref = "Grüne") + NEPAFBS + notEffectiveD, df[df$education.S2 != "Kein Abschluss/Noch in Schule",])

tab_model(lm, vcov.fun = "vcovHC", vcov.type = "HC2", show.ci = .95, show.p = T, show.aic = T, show.r2 = T, show.loglik = T, collapse.ci = F) # in text)


#### Descriptive statistics ####
#### Table 2 ####
detach("package:plyr")
tab_2 <- df %>%
    filter(Interventiontype != "Con") %>% 
    group_by(Sourcetype, Interventiontype) %>%
    summarise(
        meanttf = round(mean(ThreatToFreedomAFBS, na.rm = T),2),
        sdttf = round(sd(ThreatToFreedomAFBS, na.rm = T),2),
        medianttf = round(median(ThreatToFreedomAFBS, na.rm = T),2),
        meana = round(mean(AngerAFBS, na.rm = T),2),
        sda = round(sd(AngerAFBS, na.rm = T),2),
        mediana = round(median(AngerAFBS, na.rm = T),2),
        n = length(Contribution[!is.na(ThreatToFreedomAFBS) & !is.na(AngerAFBS)])
    )

tab_df(tab_2)


#### Table 2 for sub-scales of threat and anger ####
# Threat to freedom subscales
tab_2a <- df %>%
    filter(Interventiontype != "Con") %>% 
    group_by(Sourcetype, Interventiontype) %>%
    summarise(
        meanttf = round(mean(SRthreat1, na.rm = T),2),
        sdttf = round(sd(SRthreat1, na.rm = T),2),
        medianttf = round(median(SRthreat1, na.rm = T),2),
        n = length(Contribution[!is.na(SRthreat1)])
    )

tab_df(tab_2a, title = "The [intervention type] threatened my freedom of choice")

tab_2b <- df %>%
    filter(Interventiontype != "Con") %>% 
    group_by(Sourcetype, Interventiontype) %>%
    summarise(
        meanttf = round(mean(SRthreat2, na.rm = T),2),
        sdttf = round(sd(SRthreat2, na.rm = T),2),
        medianttf = round(median(SRthreat2, na.rm = T),2),
        n = length(Contribution[!is.na(SRthreat2)])
    )

tab_df(tab_2b, title = "The [intervention type] tries to make a decision for me")

tab_2c <- df %>%
    filter(Interventiontype != "Con") %>% 
    group_by(Sourcetype, Interventiontype) %>%
    summarise(
        meanttf = round(mean(SRthreat3, na.rm = T),2),
        sdttf = round(sd(SRthreat3, na.rm = T),2),
        medianttf = round(median(SRthreat3, na.rm = T),2),
        n = length(Contribution[!is.na(SRthreat3)])
    )

tab_df(tab_2c, title = "The [intervention type] tries to manipulate me")

tab_2d <- df %>%
    filter(Interventiontype != "Con") %>% 
    group_by(Sourcetype, Interventiontype) %>%
    summarise(
        meanttf = round(mean(SRthreat4, na.rm = T),2),
        sdttf = round(sd(SRthreat4, na.rm = T),2),
        medianttf = round(median(SRthreat4, na.rm = T),2),
        n = length(Contribution[!is.na(SRthreat4)])
    )

tab_df(tab_2d, title = "The [intervention type] tries to pressure me")

# Anger subscales
df$SRanger1 <- as.numeric(df$SRanger1)
tab_2a <- df %>%
    filter(Interventiontype != "Con") %>% 
    group_by(Sourcetype, Interventiontype) %>%
    summarise(
        meanttf = round(mean(SRanger1, na.rm = T),2),
        sdttf = round(sd(SRanger1, na.rm = T),2),
        medianttf = round(median(SRanger1, na.rm = T),2),
        n = length(Contribution[!is.na(SRanger1)])
    )

tab_df(tab_2a, title = "The [intervention type] irritated me")

tab_2b <- df %>%
    filter(Interventiontype != "Con") %>% 
    group_by(Sourcetype, Interventiontype) %>%
    summarise(
        meanttf = round(mean(SRanger2, na.rm = T),2),
        sdttf = round(sd(SRanger2, na.rm = T),2),
        medianttf = round(median(SRanger2, na.rm = T),2),
        n = length(Contribution[!is.na(SRanger2)])
    )

tab_df(tab_2b, title = "The [intervention type] made me angry")

tab_2c <- df %>%
    filter(Interventiontype != "Con") %>% 
    group_by(Sourcetype, Interventiontype) %>%
    summarise(
        meanttf = round(mean(SRanger3, na.rm = T),2),
        sdttf = round(sd(SRanger3, na.rm = T),2),
        medianttf = round(median(SRanger3, na.rm = T),2),
        n = length(Contribution[!is.na(SRanger3)])
    )

tab_df(tab_2c, title = "The [intervention type] annoyed me")

tab_2d <- df %>%
    filter(Interventiontype != "Con") %>% 
    group_by(Sourcetype, Interventiontype) %>%
    summarise(
        meanttf = round(mean(SRanger4, na.rm = T),2),
        sdttf = round(sd(SRanger4, na.rm = T),2),
        medianttf = round(median(SRanger4, na.rm = T),2),
        n = length(Contribution[!is.na(SRanger4)])
    )

tab_df(tab_2d, title = "The [intervention type] aggravated me")

#### Table B.5 ####
df$Interventiontype <- relevel(df$Interventiontype, ref = "Con")
df$Sourcetype <- relevel(df$Sourcetype, ref = "Con")
df$genderC <- ifelse(df$gender.S2 == "Male", 0,1)
df_summary_dagg <- df %>%
    group_by(Sourcetype, Interventiontype) %>%
    summarise(
        TR = round(mean(ReactanceAFBS, na.rm = T),2), 
        TR_sd = round(sd(ReactanceAFBS, na.rm = T),2),
        NEP = round(mean(NEPAFBS, na.rm = T),2),
        NEP_sd = round(sd(NEPAFBS, na.rm = T),2),
        CDU =  round(length(ac[PO == "CDU/CSU"])/length(ac[!is.na(PO)])*100,2),
        SPD = round(length(ac[PO == "SPD"])/length(ac[!is.na(PO)])*100,2),
        Green = round(length(ac[PO == "Grüne"])/length(ac[!is.na(PO)])*100,2),
        Left = round(length(ac[PO == "DieLinke"])/length(ac[!is.na(PO)])*100,2),
        AfD = round(length(ac[PO == "AfD"])/length(ac[!is.na(PO)])*100,2),
        FDP = round(length(ac[PO == "FDP"])/length(ac[!is.na(PO)])*100,2),
        Pirate = round(length(ac[PO == "Piraten"])/length(ac[!is.na(PO)])*100,2),
        NPD = round(length(ac[PO == "NPD"])/length(ac[!is.na(PO)])*100,2),
        nm =  round(length(ac[PO == "kA"])/length(ac[!is.na(PO)])*100,2),
        notEff = round(sum(notEffectiveD)/length(notEffectiveD)*100,2),
        n = length(ReactanceAFBS)
    )

df_summary_agg <- df %>%
    summarise(
        TR = round(mean(ReactanceAFBS, na.rm = T),2), 
        TR_sd = round(sd(ReactanceAFBS, na.rm = T),2),
        NEP = round(mean(NEPAFBS, na.rm = T),2), 
        NEP_sd = round(sd(NEPAFBS, na.rm = T),2),
        CDU =  round(length(ac[PO == "CDU/CSU"])/length(ac[!is.na(PO)])*100,2),
        SPD = round(length(ac[PO == "SPD"])/length(ac[!is.na(PO)])*100,2),
        Green = round(length(ac[PO == "Grüne"])/length(ac[!is.na(PO)])*100,2),
        Left = round(length(ac[PO == "DieLinke"])/length(ac[!is.na(PO)])*100,2),
        AfD = round(length(ac[PO == "AfD"])/length(ac[!is.na(PO)])*100,2),
        FDP = round(length(ac[PO == "FDP"])/length(ac[!is.na(PO)])*100,2),
        Pirate = round(length(ac[PO == "Piraten"])/length(ac[!is.na(PO)])*100,2),
        NPD = round(length(ac[PO == "NPD"])/length(ac[!is.na(PO)])*100,2),
        nm =  round(length(ac[PO == "kA"])/length(ac[!is.na(PO)])*100,2),
        notEff = round(sum(notEffectiveD)/length(notEffectiveD)*100,2),
        n = length(ReactanceAFBS)
    )

#### Table B.6 ####
df_summary_dagg <- df %>%
    group_by(Sourcetype, Interventiontype) %>%
    summarise(
        meanage = round(mean(age.S2, na.rm = T),2),
        sdage = round(sd(age.S2, na.rm = T),2),
        females = round(sum(genderC, na.rm = T)/length(ac[!is.na(genderC)])*100,2),
        noSchool = round(length(ac[education.S2 == "Kein Abschluss/Noch in Schule"])/length(ac[!is.na(education.S2)])*100,2),
        lowSchool = round(length(ac[education.S2 == "Haupt/Volkshochschule"])/length(ac[!is.na(education.S2)])*100,2),
        MidSchool = round(length(ac[education.S2 == "Realschule/Mittlere Reife"])/length(ac[!is.na(education.S2)])*100,2),
        HighSchool = round(length(ac[education.S2 == "Abitur/Fachabitur"])/length(ac[!is.na(education.S2)])*100,2),
        UniSchool = round(length(ac[education.S2 == "Hochschulabschluss"])/length(ac[!is.na(education.S2)])*100,2),
        bel600 =  round(length(ac[hh.incomeF == "<600"])/length(ac[!is.na(hh.incomeF)])*100,2),
        f600t999 =  round(length(ac[hh.incomeF == "600-999"])/length(ac[!is.na(hh.incomeF)])*100,2),
        f1000t1249 =  round(length(ac[hh.incomeF == "1,000-1,249"])/length(ac[!is.na(hh.incomeF)])*100,2),
        f1250t1499 =  round(length(ac[hh.incomeF == "1,250-1,499"])/length(ac[!is.na(hh.incomeF)])*100,2),
        f1500t1999 =  round(length(ac[hh.incomeF == "1,500-1,999"])/length(ac[!is.na(hh.incomeF)])*100,2),
        f2000t2499 =  round(length(ac[hh.incomeF == "2,000-2,499"])/length(ac[!is.na(hh.incomeF)])*100,2),
        f2500t2999 =  round(length(ac[hh.incomeF == "2,500-2,999"])/length(ac[!is.na(hh.incomeF)])*100,2),
        f3000t3499 =  round(length(ac[hh.incomeF == "3,000-3,499"])/length(ac[!is.na(hh.incomeF)])*100,2),
        f3500t3999 =  round(length(ac[hh.incomeF == "3,500-3,999"])/length(ac[!is.na(hh.incomeF)])*100,2),
        f4000t4999 =  round(length(ac[hh.incomeF == "4,000-4,999"])/length(ac[!is.na(hh.incomeF)])*100,2),
        f5000 =  round(length(ac[hh.incomeF == ">5,000"])/length(ac[!is.na(hh.incomeF)])*100,2),
        n = length(ReactanceAFBS)
    )

df_summary_agg <- df %>%
    summarise(
        meanage = round(mean(age.S2, na.rm = T),2),
        sdage = round(sd(age.S2, na.rm = T),2),
        females = round(sum(genderC, na.rm = T)/length(ac[!is.na(genderC)])*100,2),
        noSchool = round(length(ac[education.S2 == "Kein Abschluss/Noch in Schule"])/length(ac[!is.na(education.S2)])*100,4),
        lowSchool = round(length(ac[education.S2 == "Haupt/Volkshochschule"])/length(ac[!is.na(education.S2)])*100,4),
        MidSchool = round(length(ac[education.S2 == "Realschule/Mittlere Reife"])/length(ac[!is.na(education.S2)])*100,4),
        HighSchool = round(length(ac[education.S2 == "Abitur/Fachabitur"])/length(ac[!is.na(education.S2)])*100,4),
        UniSchool = round(length(ac[education.S2 == "Hochschulabschluss"])/length(ac[!is.na(education.S2)])*100,4),
        bel600 =  round(length(ac[hh.incomeF == "<600"])/length(ac[!is.na(hh.incomeF)])*100,2),
        f600t999 =  round(length(ac[hh.incomeF == "600-999"])/length(ac[!is.na(hh.incomeF)])*100,2),
        f1000t1249 =  round(length(ac[hh.incomeF == "1,000-1,249"])/length(ac[!is.na(hh.incomeF)])*100,2),
        f1250t1499 =  round(length(ac[hh.incomeF == "1,250-1,499"])/length(ac[!is.na(hh.incomeF)])*100,2),
        f1500t1999 =  round(length(ac[hh.incomeF == "1,500-1,999"])/length(ac[!is.na(hh.incomeF)])*100,2),
        f2000t2499 =  round(length(ac[hh.incomeF == "2,000-2,499"])/length(ac[!is.na(hh.incomeF)])*100,2),
        f2500t2999 =  round(length(ac[hh.incomeF == "2,500-2,999"])/length(ac[!is.na(hh.incomeF)])*100,2),
        f3000t3499 =  round(length(ac[hh.incomeF == "3,000-3,499"])/length(ac[!is.na(hh.incomeF)])*100,2),
        f3500t3999 =  round(length(ac[hh.incomeF == "3,500-3,999"])/length(ac[!is.na(hh.incomeF)])*100,2),
        f4000t4999 =  round(length(ac[hh.incomeF == "4,000-4,999"])/length(ac[!is.na(hh.incomeF)])*100,2),
        f5000 =  round(length(ac[hh.incomeF == ">5,000"])/length(ac[!is.na(hh.incomeF)])*100,2),
        n = length(ReactanceAFBS)
    )


#### Regression model output (Table 3) ####
lm1 <- (lm(ThreatToFreedomAFBS ~ Interventiontype + Sourcetype + ReactanceAFBS + baseD, df)) # (1)
lm2 <- (lm(ThreatToFreedomAFBS ~ Interventiontype*baseD + Sourcetype + ReactanceAFBS, df)) # (2)
lm3 <- (lm(ThreatToFreedomAFBS ~ Interventiontype*Sourcetype + ReactanceAFBS + baseD, df)) # (3)
lm4 <- (lm(AngerAFBS ~ Interventiontype + Sourcetype + ReactanceAFBS + baseD, df)) # (4)
lm5 <- (lm(AngerAFBS ~ Interventiontype*baseD + Sourcetype + ReactanceAFBS, df)) # (5)
lm6 <- (lm(AngerAFBS ~ Interventiontype*Sourcetype + ReactanceAFBS + baseD, df)) # (6)

tab_model(lm1,lm2,lm3,lm4,lm5,lm6, vcov.fun = "vcovHC", vcov.type = "HC2", show.ci = .95, show.p = T, p.style = "numeric", show.aic = T, show.r2 = T, show.loglik = T, collapse.ci = T)

#### Distribution of contribution changes ####
hist <- ggplot(df, aes(x = changeScore)) +
    geom_histogram() +
    theme_bw() +
    ylab("Frequency") +
    xlab("Contribution Change") +
    common_ops
    
#tikz(file = "./article/figures/hist.tex", width = 5, height = 3)
hist
#dev.off()

#### Bar graphs (Figure 1) ####
df$Interventiontype <- relevel(df$Interventiontype, ref = "Rec")
levels(df$Interventiontype) <- c("Rec", "Con", "Def", "MMC")
t <- summarySE(df, measurevar = "AngerAFBS", groupvars=c("baseD","Interventiontype"), conf.interval=.95, na.rm = T)

anger <- ggplot(t[t$Interventiontype != "Con",], aes(x = Interventiontype, y = AngerAFBS, fill = baseD)) +
    scale_y_continuous(breaks = c(seq(0,16,2)), limits = c(0, 16)) +
    geom_bar(stat = "identity", position = position_dodge(width=0.9)) +
    geom_errorbar(aes(ymin = (AngerAFBS - ci), ymax = (AngerAFBS + ci)), width = 0.25, position = position_dodge(width=0.9)) +
    labs(x = "Interventiontype", y='Mean anger score', fill='Base contribution') +
    scale_fill_grey() +
    theme_bw()+
    common_ops +
    guides(fill = guide_legend(title.position="top", title.hjust = 0.5))

t <- summarySE(df, measurevar = "ThreatToFreedomAFBS", groupvars=c("baseD", "Interventiontype"), conf.interval=.95, na.rm = T)

threat <- ggplot(t[t$Interventiontype != "Con",],
                 aes(x = Interventiontype, y = ThreatToFreedomAFBS, fill = baseD)) +
    scale_y_continuous(breaks = c(seq(0,16,2)), limits = c(0, 16)) +
    geom_bar(stat = "identity", position = position_dodge(width=0.9)) +
    geom_errorbar(aes(ymin = (ThreatToFreedomAFBS - ci), ymax = (ThreatToFreedomAFBS + ci)), width = 0.25, position = position_dodge(width=0.9)) +
    labs(x = "Interventiontype", y='Mean threat to\nfreedom score', fill='Base contribution') +
    scale_fill_grey() +
    theme_bw()+
    common_ops +
    guides(fill = guide_legend(title.position="top", title.hjust = 0.5))

multiplot(threat, anger, cols=2)


#### Bar graphs disaggregated by state reactance subscales ####
# Threat to freedom
df$Interventiontype <- relevel(df$Interventiontype, ref = "Rec")
levels(df$Interventiontype) <- c("Rec", "Con", "Def", "MMC")
t <- summarySE(df, measurevar = "SRthreat1", groupvars=c("baseD","Interventiontype"), conf.interval=.95, na.rm = T)

threat1 <- ggplot(t[t$Interventiontype != "Con",], aes(x = Interventiontype, y = SRthreat1, fill = baseD)) +
    scale_y_continuous(breaks = c(seq(0,4,1)), limits = c(0, 4)) +
    geom_bar(stat = "identity", position = position_dodge(width=0.9)) +
    geom_errorbar(aes(ymin = (SRthreat1 - ci), ymax = (SRthreat1 + ci)), width = 0.25, position = position_dodge(width=0.9)) +
    labs(x = "Interventiontype", title='The [intervention type] threatened my freedom of choice', y = 'Mean response', fill='Base contribution') +
    scale_fill_grey() +
    theme_bw()+
    common_ops +
    guides(fill = guide_legend(title.position="top", title.hjust = 0.5))

t <- summarySE(df, measurevar = "SRthreat2", groupvars=c("baseD", "Interventiontype"), conf.interval=.95, na.rm = T)

threat2 <- ggplot(t[t$Interventiontype != "Con",],
                 aes(x = Interventiontype, y = SRthreat2, fill = baseD)) +
    scale_y_continuous(breaks = c(seq(0,4,1)), limits = c(0, 4)) +
    geom_bar(stat = "identity", position = position_dodge(width=0.9)) +
    geom_errorbar(aes(ymin = (SRthreat2 - ci), ymax = (SRthreat2 + ci)), width = 0.25, position = position_dodge(width=0.9)) +
    labs(x = "Interventiontype", title='The [intervention type] tries to make a decision for me', y = 'Mean response', fill='Base contribution') +
    scale_fill_grey() +
    theme_bw()+
    common_ops +
    guides(fill = guide_legend(title.position="top", title.hjust = 0.5))

t <- summarySE(df, measurevar = "SRthreat3", groupvars=c("baseD", "Interventiontype"), conf.interval=.95, na.rm = T)

threat3 <- ggplot(t[t$Interventiontype != "Con",],
                 aes(x = Interventiontype, y = SRthreat3, fill = baseD)) +
    scale_y_continuous(breaks = c(seq(0,4,1)), limits = c(0, 4)) +
    geom_bar(stat = "identity", position = position_dodge(width=0.9)) +
    geom_errorbar(aes(ymin = (SRthreat3 - ci), ymax = (SRthreat3 + ci)), width = 0.25, position = position_dodge(width=0.9)) +
    labs(x = "Interventiontype", title='The [intervention type] tries to manipulate me', y = 'Mean response', fill='Base contribution') +
    scale_fill_grey() +
    theme_bw()+
    common_ops +
    guides(fill = guide_legend(title.position="top", title.hjust = 0.5))

t <- summarySE(df, measurevar = "SRthreat4", groupvars=c("baseD", "Interventiontype"), conf.interval=.95, na.rm = T)

threat4 <- ggplot(t[t$Interventiontype != "Con",],
                 aes(x = Interventiontype, y = SRthreat4, fill = baseD)) +
    scale_y_continuous(breaks = c(seq(0,4,1)), limits = c(0, 4)) +
    geom_bar(stat = "identity", position = position_dodge(width=0.9)) +
    geom_errorbar(aes(ymin = (SRthreat4 - ci), ymax = (SRthreat4 + ci)), width = 0.25, position = position_dodge(width=0.9)) +
    labs(x = "Interventiontype", title = 'The [intervention type] tries to pressure me', y='Mean response', fill='Base contribution') +
    scale_fill_grey() +
    theme_bw()+
    common_ops +
    guides(fill = guide_legend(title.position="top", title.hjust = 0.5))

multiplot(threat1, threat2, threat3, threat4, cols=2)

# Anger
df$Interventiontype <- relevel(df$Interventiontype, ref = "Rec")
levels(df$Interventiontype) <- c("Rec", "Con", "Def", "MMC")
t <- summarySE(df, measurevar = "SRanger1", groupvars=c("baseD","Interventiontype"), conf.interval=.95, na.rm = T)

anger1 <- ggplot(t[t$Interventiontype != "Con",], aes(x = Interventiontype, y = SRanger1, fill = baseD)) +
    scale_y_continuous(breaks = c(seq(0,4,2)), limits = c(0, 4)) +
    geom_bar(stat = "identity", position = position_dodge(width=0.9)) +
    geom_errorbar(aes(ymin = (SRanger1 - ci), ymax = (SRanger1 + ci)), width = 0.25, position = position_dodge(width=0.9)) +
    labs(x = "Interventiontype", title='The [intervention type] irritated me', y = 'Mean response', fill='Base contribution') +
    scale_fill_grey() +
    theme_bw()+
    common_ops +
    guides(fill = guide_legend(title.position="top", title.hjust = 0.5))

t <- summarySE(df, measurevar = "SRanger2", groupvars=c("baseD", "Interventiontype"), conf.interval=.95, na.rm = T)

anger2 <- ggplot(t[t$Interventiontype != "Con",],
                 aes(x = Interventiontype, y = SRanger2, fill = baseD)) +
    scale_y_continuous(breaks = c(seq(0,4,2)), limits = c(0, 4)) +
    geom_bar(stat = "identity", position = position_dodge(width=0.9)) +
    geom_errorbar(aes(ymin = (SRanger2 - ci), ymax = (SRanger2 + ci)), width = 0.25, position = position_dodge(width=0.9)) +
    labs(x = "Interventiontype", title='The [intervention type] made me angry', y = 'Mean response', fill='Base contribution') +
    scale_fill_grey() +
    theme_bw()+
    common_ops +
    guides(fill = guide_legend(title.position="top", title.hjust = 0.5))

t <- summarySE(df, measurevar = "SRanger3", groupvars=c("baseD", "Interventiontype"), conf.interval=.95, na.rm = T)

anger3 <- ggplot(t[t$Interventiontype != "Con",],
                 aes(x = Interventiontype, y = SRanger3, fill = baseD)) +
    scale_y_continuous(breaks = c(seq(0,4,2)), limits = c(0, 4)) +
    geom_bar(stat = "identity", position = position_dodge(width=0.9)) +
    geom_errorbar(aes(ymin = (SRanger3 - ci), ymax = (SRanger3 + ci)), width = 0.25, position = position_dodge(width=0.9)) +
    labs(x = "Interventiontype", title='The [intervention type] annoyed me', y = 'Mean response', fill='Base contribution') +
    scale_fill_grey() +
    theme_bw()+
    common_ops +
    guides(fill = guide_legend(title.position="top", title.hjust = 0.5))

t <- summarySE(df, measurevar = "SRanger4", groupvars=c("baseD", "Interventiontype"), conf.interval=.95, na.rm = T)

anger4 <- ggplot(t[t$Interventiontype != "Con",],
                 aes(x = Interventiontype, y = SRanger4, fill = baseD)) +
    scale_y_continuous(breaks = c(seq(0,4,2)), limits = c(0, 4)) +
    geom_bar(stat = "identity", position = position_dodge(width=0.9)) +
    geom_errorbar(aes(ymin = (SRanger4 - ci), ymax = (SRanger4 + ci)), width = 0.25, position = position_dodge(width=0.9)) +
    labs(x = "Interventiontype", title='The [intervention type] aggravated me', y = 'Mean response', fill='Base contribution') +
    scale_fill_grey() +
    theme_bw()+
    common_ops +
    guides(fill = guide_legend(title.position="top", title.hjust = 0.5))

multiplot(anger1, anger2, anger3, anger4, cols=2)




#### T- tests (extending F1) ####
t.test(df$ThreatToFreedomAFBS[df$baseD == ">35" & (df$Interventiontype == "Res" | df$Interventiontype == "Def")] ~ df$Interventiontype[df$baseD == ">35" & (df$Interventiontype == "Res" | df$Interventiontype == "Def")])
t.test(df$AngerAFBS[df$baseD == ">35" & (df$Interventiontype == "Res" | df$Interventiontype == "Def")] ~ df$Interventiontype[df$baseD == ">35" & (df$Interventiontype == "Res" | df$Interventiontype == "Def")])


#### F2 extensions (in text, logit regressions) ####
glm1 <- glm(SourceKnowledgeD ~ Sourcetype, df[df$Sourcetype != "NoS" & df$Sourcetype != "Con",], family = binomial("logit"))
glm2 <- glm(SourceReductionD ~ Sourcetype, df[df$Sourcetype != "NoS" & df$Sourcetype != "Con",], family = binomial("logit"))
glm3 <- glm(SourceInfluenceD ~ Sourcetype, df[df$Sourcetype != "NoS" & df$Sourcetype != "Con",], family = binomial("logit"))

glm1a <- glm(SourceKnowledgeD ~ Interventiontype, df[df$Sourcetype != "NoS" & df$Sourcetype != "Con",], family = binomial("logit"))
glm2a <- glm(SourceReductionD ~ Interventiontype, df[df$Sourcetype != "NoS" & df$Sourcetype != "Con",], family = binomial("logit"))
glm3a <- glm(SourceInfluenceD ~ Interventiontype, df[df$Sourcetype != "NoS" & df$Sourcetype != "Con",], family = binomial("logit"))

glm1b <- glm(SourceKnowledgeD ~ Interventiontype*Sourcetype, df[df$Sourcetype != "NoS" & df$Sourcetype != "Con",], family = binomial("logit"))
glm2b <- glm(SourceReductionD ~ Interventiontype*Sourcetype, df[df$Sourcetype != "NoS" & df$Sourcetype != "Con",], family = binomial("logit"))
glm3b <- glm(SourceInfluenceD ~ Interventiontype*Sourcetype, df[df$Sourcetype != "NoS" & df$Sourcetype != "Con",], family = binomial("logit"))


tab_model(glm1, glm2, glm3, vcov.fun = "vcovHC", vcov.type = "HC2", show.ci = .95, show.p = T, p.style = "numeric", show.aic = T, show.r2 = T, show.loglik = T, collapse.ci = T) # in text
tab_model(glm1, glm2, glm3, glm1a, glm2a, glm3a,glm1b, glm2b, glm3b, vcov.fun = "vcovHC", vcov.type = "HC2", show.ci = .95, show.p = T, p.style = "numeric", show.aic = T, show.r2 = T, show.loglik = T, collapse.ci = T) # robustness checks


lm1 <- lm(ThreatToFreedomAFBS ~ SourceKnowledgeD + SourceInfluenceD + SourceReductionD, df)
lm2 <- lm(AngerAFBS ~ SourceKnowledgeD + SourceInfluenceD + SourceReductionD, df)

tab_model(lm1, lm2, vcov.fun = "vcovHC", vcov.type = "HC2", show.ci = .95, show.p = T, p.style = "numeric", show.aic = T, show.r2 = T, show.loglik = T, collapse.ci = T) # in text


#### Mediated moderation (Finding 3) ####
## See Stata script (analyses.do) for the structural equation models ##


#### Correlation between Threat perception and Anger ####
cor.test(df$ThreatToFreedomAFBS, df$AngerAFBS, alternative = "two.sided", use = "complete.obs", method = "spearman")



#### PCA with varimax rotation & Cronbach's alpha ####
## For threat to freedom
threatdf <- df %>% 
    select(SRthreat1, SRthreat2, SRthreat3, SRthreat4) %>% 
    filter(!is.na(SRthreat1), !is.na(SRthreat2), !is.na(SRthreat3), !is.na(SRthreat4))

results <- prcomp(threatdf, scale = T)
results$rotation <- -1*results$rotation #https://www.statology.org/principal-components-analysis-in-r/
results$rotation
biplot(results, scale = 0)

#calculate total variance explained by each principal component
results$sdev^2 / sum(results$sdev^2)
# The first principal component explains 84.53 % of the total variance in the dataset, which suggests unidimensionality.

#calculate total variance explained by each principal component
var_explained = results$sdev^2 / sum(results$sdev^2)

#create scree plot
ggplot(as.data.frame(var_explained)) +
    geom_line(aes(x= seq(1:4), y = var_explained))+
    geom_point(aes(x= seq(1:4), y = var_explained)) +
    scale_y_continuous(limits = c(0,1)) +
    xlab("Principal Component") + 
    ylab("Variance Explained") +
    ggtitle("Scree Plot (displays the total variance explained by each principal component)") +
    theme_bw() +
    common_ops


alpha_threat <- cronbach.alpha(threatdf)


## For anger
angerdf <- df %>% 
    select(SRanger1, SRanger2, SRanger3, SRanger4) %>% 
    filter(!is.na(SRanger1), !is.na(SRanger2), !is.na(SRanger3), !is.na(SRanger4))

angerdf$SRanger1 <- as.numeric(angerdf$SRanger1)
angerdf$SRanger2 <- as.numeric(angerdf$SRanger2)
angerdf$SRanger3 <- as.numeric(angerdf$SRanger3)
angerdf$SRanger4 <- as.numeric(angerdf$SRanger4)

results <- prcomp(angerdf, scale = T)
results$rotation <- -1*results$rotation #https://www.statology.org/principal-components-analysis-in-r/
results$rotation
biplot(results, scale = 0)

#calculate total variance explained by each principal component
results$sdev^2 / sum(results$sdev^2)
# The first principal component explains 64.76% of the total variance in the dataset, which suggests unidimensionality, although less so than for the threat case. 
# Principal components two and three explain 16.7% and  14.34%, respectively.

#calculate total variance explained by each principal component
var_explained = results$sdev^2 / sum(results$sdev^2)

#create scree plot
ggplot(as.data.frame(var_explained)) +
    geom_line(aes(x= seq(1:4), y = var_explained))+
    geom_point(aes(x= seq(1:4), y = var_explained)) +
    scale_y_continuous(limits = c(0,1)) +
    xlab("Principal Component") + 
    ylab("Variance Explained") +
    ggtitle("Scree Plot (displays the total variance explained by each principal component)") +
    theme_bw() +
    common_ops


alpha_anger <- cronbach.alpha(angerdf)



# For trait reactance
as.numeric(df$TR.TR1.) + as.numeric(df$TR.TR3.) + as.numeric(df$TR.TR10.)

trdf <- df %>% 
    select(TR.TR1.,TR.TR2.,TR.TR3.,TR.TR4.,TR.TR5.,TR.TR6.,TR.TR7.,TR.TR8.,TR.TR9.,TR.TR10.,TR.TR11.,) 

trdf$TR.TR1. <- as.numeric(trdf$TR.TR1.)
trdf$TR.TR2. <- as.numeric(trdf$TR.TR2.)
trdf$TR.TR3. <- as.numeric(trdf$TR.TR3.)
trdf$TR.TR4. <- as.numeric(trdf$TR.TR4.)
trdf$TR.TR5. <- as.numeric(trdf$TR.TR5.)
trdf$TR.TR6. <- as.numeric(trdf$TR.TR6.)
trdf$TR.TR7. <- as.numeric(trdf$TR.TR7.)
trdf$TR.TR8. <- as.numeric(trdf$TR.TR8.)
trdf$TR.TR9. <- as.numeric(trdf$TR.TR9.)
trdf$TR.TR10. <- as.numeric(trdf$TR.TR10.)
trdf$TR.TR11. <- as.numeric(trdf$TR.TR11.)


results <- prcomp(trdf, scale = T)
results$rotation <- -1*results$rotation #https://www.statology.org/principal-components-analysis-in-r/
results$rotation
biplot(results, scale = 0)

#calculate total variance explained by each principal component
results$sdev^2 / sum(results$sdev^2)
# The first principal component explains 64.76% of the total variance in the dataset, which suggests unidimensionality, although less so than for the threat case. 
# Principal components two and three explain 16.7% and  14.34%, respectively.

#calculate total variance explained by each principal component
var_explained = results$sdev^2 / sum(results$sdev^2)

#create scree plot
ggplot(as.data.frame(var_explained)) +
    geom_line(aes(x= seq(1:11), y = var_explained))+
    geom_point(aes(x= seq(1:11), y = var_explained)) +
    scale_y_continuous(limits = c(0,1)) +
    xlab("Principal Component") + 
    ylab("Variance Explained") +
    ggtitle("Scree Plot (displays the total variance explained by each principal component)") +
    theme_bw() +
    common_ops


alpha_tr <- cronbach.alpha(trdf)
